@@ -8,7 +8,7 @@
 
 glmnet.lasso <- function(x, y, q, type = c("conservative", "anticonservative"), ...) {
     if (!requireNamespace("glmnet", quietly=TRUE))
-        stop("Package ", sQuote("glmnet"), " needed but not available")
+        stop("Package ", sQuote("glmnet"), " needed but not available. Please install the package.")
     
     if (is.data.frame(x)) {
         message("Note: ", sQuote("x"),
@@ -18,7 +18,7 @@ glmnet.lasso <- function(x, y, q, type = c("conservative", "anticonservative"),
     
     if ("lambda" %in% names(list(...)))
         stop("It is not permitted to specify the penalty parameter ", sQuote("lambda"),
-             " for lasso when used with stability selection.")
+             " for ", sQuote("glmnet.lasso"))
     
     ## fit model
     type <- match.arg(type)
@@ -42,7 +42,7 @@ glmnet.lasso <- function(x, y, q, type = c("conservative", "anticonservative"),
 
 lars.lasso <- function(x, y, q, ...) {
     if (!requireNamespace("lars", quietly=TRUE))
-        stop("Package ", sQuote("lars"), " needed but not available")
+        stop("Package ", sQuote("lars"), " needed but not available. Please install the package.")
 
     if (is.data.frame(x)) {
         message("Note: ", sQuote("x"),
@@ -75,7 +75,7 @@ lars.lasso <- function(x, y, q, ...) {
 
 lars.stepwise <- function(x, y, q, ...) {
     if (!requireNamespace("lars", quietly=TRUE))
-        stop("Package ", sQuote("lars"), " needed but not available")
+        stop("Package ", sQuote("lars"), " needed but not available. Please install the package.")
 
     if (is.data.frame(x)) {
         message("Note: ", sQuote("x"),
@@ -108,7 +108,7 @@ lars.stepwise <- function(x, y, q, ...) {
 
 glmnet.lasso_maxCoef <- function(x, y, q, ...) {
     if (!requireNamespace("glmnet", quietly=TRUE))
-        stop("Package ", sQuote("glmnet"), " needed but not available")
+        stop("Package ", sQuote("glmnet"), " needed but not available. Please install the package.")
 
     if (is.data.frame(x)) {
         message("Note: ", sQuote("x"),
@@ -118,15 +118,15 @@ glmnet.lasso_maxCoef <- function(x, y, q, ...) {
 
     args <- list(...)
     if (!("lambda" %in% names(args)) && length(args$lambda) != 1)
-        stop("Please specify a fixed (!) value of ", sQuote("lambda"),
-             ", which is small enough that at least ", sQuote("q"),
+        stop("Please specify a fixed penalty parameter ", sQuote("lambda"),
+             ",\nwhich is small enough that at least ", sQuote("q"),
              " variables can be selected.")
 
     ## fit model
     fit <- glmnet::glmnet(x, y, ...)
 
     ## which coefficients are the q biggest
-    selected <- order(coef(fit)[-1])[1:q]
+    selected <- order(abs(coef(fit)[-1]), decreasing = TRUE)[1:q]
     ret <- logical(ncol(x))
     ret[selected] <- TRUE
     names(ret) <- colnames(x)
