@@ -188,8 +188,14 @@ stabsel_parameters.default <- function(p, cutoff, q, PFER,
     if ((!missing(PFER) || !missing(FWER)) && PFER < 0)
         stop(sQuote("PFER"), " must be greater 0")
 
-    if (!missing(cutoff) && (cutoff < 0.5 | cutoff > 1))
+    if (!missing(cutoff) && assumption != "r-concave" && (cutoff < 0.5 | cutoff > 1))
         stop(sQuote("cutoff"), " must be between 0.5 and 1")
+    
+    ## in case of r-concavity the threshold might be less than 0.5
+    ## as q might not be specified it first needs to be computed and threshold should be rechecked then
+    if (!missing(cutoff) && assumption == "r-concave" && (cutoff < 0 | cutoff > 1))
+      stop(sQuote("cutoff"), " must be between 0 and 1")
+    
 
     if (!missing(q)) {
         if (p < q)
@@ -243,6 +249,11 @@ stabsel_parameters.default <- function(p, cutoff, q, PFER,
                     " for the given value of ", sQuote("cutoff"),
                     " (true upper bound = ", upperbound, ")")
     }
+    
+    ## in case of r-concavity the threshold might be less than 0.5 but larger than q/p
+    if (!missing(cutoff) && assumption == "r-concave" && cutoff <= q/p)
+      stop(sQuote("cutoff"), " must be larger than q/p")
+    
 
     if (missing(PFER)) {
         if (assumption == "none") {
@@ -301,8 +312,39 @@ run_stabsel <- function(fitter, args.fitter,
                       args.fitfun = args.fitter, ...)
     }
 
-    ## if any errors occured remove results and issue a warning
-    if (any(idx <- sapply(res, is.character))) {
+    idx <- sapply(res, is.character)
+    
+    ## if all folds produce an error stop here and provide clean error messages if possible
+    if (all(idx)) {
+      ## if the package is missing extract error message and repeat it
+      if (grepl("Package (.*) needed but not available. Please install the package.", res[[1]])) {
+          txt <- gsub(".*(Package .* needed but not available. Please install the package.).*", "\\1",
+                      res[[1]])
+          stop(txt)
+      }
+      ## if penalty parameter is missing or not a fixed value
+      if (grepl("Please specify a fixed penalty parameter", res[[1]])) {
+          txt <- gsub(".*(Please specify a fixed penalty parameter .* can be selected).*", "\\1",
+                      res[[1]])
+          txt <- paste0(txt, ".\nThe penalty parameter can be specified via ", 
+                        sQuote("args.fitfun = list(lambda = .)"))
+          stop(txt)
+      }
+      ## if penalty parameter is specified but not permitted
+      if (grepl("It is not permitted to specify the penalty parameter", res[[1]])) {
+        txt <- gsub(".*(It is not permitted to specify the penalty parameter(.*)).*", "\\1",
+                    res[[1]])
+        stop(txt)
+      }
+      
+      ## else provide error messages as is  
+      stop("The model could not be fitted on any fold.\n",
+           "Please see original error messages for a solution:\n\n",
+           sapply(res[idx], function(x) x))
+    }
+    
+    ## if any errors occurred remove results and issue a warning
+    if (any(idx)) {
         warning(sum(idx), " fold(s) encountered an error. ",
                 "Results are based on ", ncol(folds) - sum(idx),
                 " folds only.\n",
